import React from 'react';
import { Logo } from '../Logo';
import { CreditCardProps } from './types';
import {
    DivStyledCreditCard,
    DivStyledFlex,
    DivStyledFlexEnd,
    DivStyledFlexText,
    PStyledDigits,
    PStyledText,
} from './CreditCard.styles';
import { iconTypes } from '../Icon';
import { Tooltip } from '../Tooltip';
import { Button } from '../Button';

const CreditCard: React.FC<CreditCardProps> = ({
    brand,
    expiresAt,
    isExpired,
    isRemovable = true,
    lastDigits,
    name,
    onRemove,
    pressed,
    ...props
}: CreditCardProps) => {
    return (
        <DivStyledCreditCard
            brand={brand}
            data-testid="test-credit-card"
            isExpired={isExpired}
            pressed={pressed}
            {...props}
        >
            <DivStyledFlexEnd>
                <Tooltip
                    children={
                        <>
                            {(isRemovable || isExpired) && (
                                <Button
                                    icon={iconTypes.bin}
                                    iconColor={'red'}
                                    iconLayout={'icon-only'}
                                    isTransparent={true}
                                    onClick={() => onRemove && onRemove()}
                                    size={'small'}
                                    theme={'secondary'}
                                />
                            )}
                        </>
                    }
                    content="Remove"
                    position="bottom"
                />
            </DivStyledFlexEnd>
            <PStyledDigits data-testid="test-credit-card-digits">{`•••• ${lastDigits}`}</PStyledDigits>
            <DivStyledFlex>
                <DivStyledFlexText>
                    <PStyledText
                        data-testid="test-credit-card-name"
                        isExpired={false}
                    >
                        {name}
                    </PStyledText>
                    <PStyledText
                        data-testid="test-credit-card-exp"
                        isExpired={isExpired}
                    >
                        {`${expiresAt.month} / ${expiresAt.year}`}{' '}
                        {isExpired && '*expired'}
                    </PStyledText>
                </DivStyledFlexText>
                <Logo
                    data-testid="test-credit-card-logo"
                    size="small"
                    theme={brand}
                />
            </DivStyledFlex>
        </DivStyledCreditCard>
    );
};

export default CreditCard;
